@@ -1,9 +1,7 @@
 import asyncio
 import dataclasses
 import mimetypes
-import os
 from pathlib import Path
-import re
 import threading
 import aiohttp
 from aiohttp import web
@@ -14,19 +12,15 @@ from collections import deque
 import time
 import uuid
 
-import urllib
-
 from rubpy.bot.enums import ChatKeypadTypeEnum, UpdateTypeEnum
 from rubpy.bot.filters import Filter
-from rubpy.bot.models import Keypad, InlineMessage, Update, Message
-from rubpy.bot.models.bot import Bot
-from rubpy.bot.models.chat import Chat
-from rubpy.bot.models.message import MessageId
+from rubpy.bot.models import Keypad, InlineMessage, Update, Message, MessageId, Chat, Bot
 
 # Setup logging
 # logging.basicConfig(level=logging.ERROR)
 logger = logging.getLogger(__name__)
 
+
 def has_time_passed(last_time, seconds: int = 5) -> bool:
     try:
         timestamp = int(float(last_time))
@@ -35,6 +29,7 @@ def has_time_passed(last_time, seconds: int = 5) -> bool:
     except (TypeError, ValueError):
         return False
 
+
 class BotClient:
     def __init__(self, token: str, rate_limit: float = 0.5, use_webhook: bool = False):
         self.token = token
@@ -75,22 +70,29 @@ class BotClient:
             async with self.session.post(url, json=data) as response:
                 if response.status != 200:
                     text = await response.text()
-                    logger.error(f"Request failed: {method} status={response.status} body={text}")
-                    raise aiohttp.ClientResponseError(response.request_info, response.history, status=response.status, message=text)
+                    logger.error(
+                        f"Request failed: {method} status={response.status} body={text}"
+                    )
+                    raise aiohttp.ClientResponseError(
+                        response.request_info,
+                        response.history,
+                        status=response.status,
+                        message=text,
+                    )
                 result = await response.json()
                 logger.debug(f"API response for {method}: {result}")
 
-                if result['status'] != 'OK':
+                if result["status"] != "OK":
                     logger.error(f"API error in {method}: {result}")
                     raise
-                return result['data']
+                return result["data"]
         except Exception as e:
             logger.error(f"Error in _make_request for {method}: {str(e)}")
             return {"status": "ERROR", "error": str(e)}
 
     async def get_me(self) -> Bot:
-        result = await self._make_request('getMe', {})
-        return Bot(**result['bot'])
+        result = await self._make_request("getMe", {})
+        return Bot(**result["bot"])
 
     async def send_message(
         self,
@@ -100,24 +102,24 @@ class BotClient:
         inline_keypad: Optional[Keypad] = None,
         disable_notification: bool = False,
         reply_to_message_id: Optional[str] = None,
-        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE
+        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE,
     ) -> MessageId:
         payload = {
-            'chat_id': chat_id,
-            'text': text,
-            'disable_notification': disable_notification,
-            'chat_keypad_type': chat_keypad_type.value,
+            "chat_id": chat_id,
+            "text": text,
+            "disable_notification": disable_notification,
+            "chat_keypad_type": chat_keypad_type.value,
         }
         if chat_keypad:
-            payload['chat_keypad'] = dataclasses.asdict(chat_keypad)
+            payload["chat_keypad"] = dataclasses.asdict(chat_keypad)
         if inline_keypad:
-            payload['inline_keypad'] = dataclasses.asdict(inline_keypad)
+            payload["inline_keypad"] = dataclasses.asdict(inline_keypad)
         if reply_to_message_id:
-            payload['reply_to_message_id'] = str(reply_to_message_id)
+            payload["reply_to_message_id"] = str(reply_to_message_id)
 
-        result = await self._make_request('sendMessage', payload)
-        result['chat_id'] = chat_id
-        result['client'] = self
+        result = await self._make_request("sendMessage", payload)
+        result["chat_id"] = chat_id
+        result["client"] = self
         return MessageId(**result)
 
     async def send_sticker(
@@ -128,26 +130,26 @@ class BotClient:
         inline_keypad: Optional[Keypad] = None,
         disable_notification: bool = False,
         reply_to_message_id: Optional[str] = None,
-        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE
+        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE,
     ) -> MessageId:
         payload = {
-            'chat_id': chat_id,
-            'sticker_id': sticker_id,
-            'disable_notification': disable_notification,
-            'chat_keypad_type': chat_keypad_type.value,
+            "chat_id": chat_id,
+            "sticker_id": sticker_id,
+            "disable_notification": disable_notification,
+            "chat_keypad_type": chat_keypad_type.value,
         }
         if chat_keypad:
-            payload['chat_keypad'] = dataclasses.asdict(chat_keypad)
+            payload["chat_keypad"] = dataclasses.asdict(chat_keypad)
         if inline_keypad:
-            payload['inline_keypad'] = dataclasses.asdict(inline_keypad)
+            payload["inline_keypad"] = dataclasses.asdict(inline_keypad)
         if reply_to_message_id:
-            payload['reply_to_message_id'] = str(reply_to_message_id)
+            payload["reply_to_message_id"] = str(reply_to_message_id)
 
-        result = await self._make_request('sendSticker', payload)
-        result['chat_id'] = chat_id
-        result['client'] = self
+        result = await self._make_request("sendSticker", payload)
+        result["chat_id"] = chat_id
+        result["client"] = self
         return MessageId(**result)
-    
+
     async def send_file(
         self,
         chat_id: str,
@@ -155,12 +157,12 @@ class BotClient:
         file_id: Optional[str] = None,
         text: Optional[str] = None,
         file_name: Optional[str] = None,
-        type: Literal['File', 'Image', 'Voice', 'Music', 'Gif', 'Video'] = 'File',
+        type: Literal["File", "Image", "Voice", "Music", "Gif", "Video"] = "File",
         chat_keypad: Optional[Keypad] = None,
         inline_keypad: Optional[Keypad] = None,
         disable_notification: bool = False,
         reply_to_message_id: Optional[str] = None,
-        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE
+        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE,
     ) -> MessageId:
         if file:
             file_name = file_name or Path(file).name
@@ -168,39 +170,44 @@ class BotClient:
             file_id = await self.upload_file(upload_url, file_name, file)
 
         payload = {
-            'chat_id': chat_id,
-            'file_id': file_id,
-            'text': text,
-            'disable_notification': disable_notification,
-            'chat_keypad_type': chat_keypad_type.value,
+            "chat_id": chat_id,
+            "file_id": file_id,
+            "text": text,
+            "disable_notification": disable_notification,
+            "chat_keypad_type": chat_keypad_type.value,
         }
         if chat_keypad:
-            payload['chat_keypad'] = dataclasses.asdict(chat_keypad)
+            payload["chat_keypad"] = dataclasses.asdict(chat_keypad)
         if inline_keypad:
-            payload['inline_keypad'] = dataclasses.asdict(inline_keypad)
+            payload["inline_keypad"] = dataclasses.asdict(inline_keypad)
         if reply_to_message_id:
-            payload['reply_to_message_id'] = str(reply_to_message_id)
+            payload["reply_to_message_id"] = str(reply_to_message_id)
 
-        result = await self._make_request('sendFile', payload)
-        result['chat_id'] = chat_id
-        result['client'] = self
-        result['file_id'] = file_id
+        result = await self._make_request("sendFile", payload)
+        result["chat_id"] = chat_id
+        result["client"] = self
+        result["file_id"] = file_id
         return MessageId(**result)
-    
-    async def request_send_file(self, type: Literal['File', 'Image', 'Voice', 'Music', 'Gif', 'Video']) -> str:
-        if type not in ['File', 'Image', 'Voice', 'Music', 'Gif', 'Video']:
-            raise ValueError("type is just be in ['File', 'Image', 'Voice', 'Music', 'Gif', 'Video']")
 
-        result = await self._make_request('requestSendFile', {'type': type})
-        return result['upload_url']
-    
+    async def request_send_file(
+        self, type: Literal["File", "Image", "Voice", "Music", "Gif", "Video"]
+    ) -> str:
+        if type not in ["File", "Image", "Voice", "Music", "Gif", "Video"]:
+            raise ValueError(
+                "type is just be in ['File', 'Image', 'Voice', 'Music', 'Gif', 'Video']"
+            )
+
+        result = await self._make_request("requestSendFile", {"type": type})
+        print(result)
+        return result["upload_url"]
+
     async def upload_file(self, url: str, file_name: str, file_path: str) -> str:
         form = aiohttp.FormData()
         form.add_field(
-            name='file',
-            value=open(file_path, 'rb'),
+            name="file",
+            value=open(file_path, "rb"),
             filename=file_name,
-            content_type='application/octet-stream'  # یا نوع فایل واقعی مثل image/png
+            content_type="application/octet-stream",  # یا نوع فایل واقعی مثل image/png
         )
 
         async with aiohttp.ClientSession() as session:
@@ -212,18 +219,24 @@ class BotClient:
                     )
 
                 data = await res.json()
-                return data['data']['file_id']  # اطمینان حاصل کن که ساختار JSON این‌طوریه
-    
-    async def get_file(self, file_id: str) -> str:
-        result = await self._make_request('getFile', {'file_id': file_id})
-        return result['download_url']
+                return data["data"][
+                    "file_id"
+                ]  # اطمینان حاصل کن که ساختار JSON این‌طوریه
 
-    async def send_poll(self, chat_id: str, question: str, options: List[str]) -> MessageId:
-        result = await self._make_request('sendPoll', {'chat_id': chat_id, 'question': question, 'options': options})
-        result['chat_id'] = chat_id
-        result['client'] = self
+    async def get_file(self, file_id: str) -> str:
+        result = await self._make_request("getFile", {"file_id": file_id})
+        return result["download_url"]
+
+    async def send_poll(
+        self, chat_id: str, question: str, options: List[str]
+    ) -> MessageId:
+        result = await self._make_request(
+            "sendPoll", {"chat_id": chat_id, "question": question, "options": options}
+        )
+        result["chat_id"] = chat_id
+        result["client"] = self
         return MessageId(**result)
-    
+
     async def send_location(
         self,
         chat_id: str,
@@ -233,20 +246,24 @@ class BotClient:
         inline_keypad: Optional[Keypad] = None,
         disable_notification: bool = False,
         reply_to_message_id: Optional[str] = None,
-        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE
+        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE,
     ) -> MessageId:
-        payload = {'chat_id': chat_id, 'latitude': str(latitude), 'longitude': str(longitude),
-                   "disable_notification": disable_notification,
-                    "chat_keypad_type": chat_keypad_type.value}
+        payload = {
+            "chat_id": chat_id,
+            "latitude": str(latitude),
+            "longitude": str(longitude),
+            "disable_notification": disable_notification,
+            "chat_keypad_type": chat_keypad_type.value,
+        }
         if chat_keypad:
             payload["chat_keypad"] = dataclasses.asdict(chat_keypad)
         if inline_keypad:
             payload["inline_keypad"] = dataclasses.asdict(inline_keypad)
         if reply_to_message_id:
             payload["reply_to_message_id"] = str(reply_to_message_id)
-        result = await self._make_request('sendLocation', payload)
-        result['chat_id'] = chat_id
-        result['client'] = self
+        result = await self._make_request("sendLocation", payload)
+        result["chat_id"] = chat_id
+        result["client"] = self
         return MessageId(**result)
 
     async def send_contact(
@@ -259,15 +276,15 @@ class BotClient:
         inline_keypad: Optional[Keypad] = None,
         disable_notification: bool = False,
         reply_to_message_id: Optional[str] = None,
-        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE
+        chat_keypad_type: ChatKeypadTypeEnum = ChatKeypadTypeEnum.NONE,
     ) -> MessageId:
         payload = {
-            'chat_id': chat_id,
-            'first_name': first_name,
-            'last_name': last_name,
-            'phone_number': phone_number,
+            "chat_id": chat_id,
+            "first_name": first_name,
+            "last_name": last_name,
+            "phone_number": phone_number,
             "disable_notification": disable_notification,
-            "chat_keypad_type": chat_keypad_type.value
+            "chat_keypad_type": chat_keypad_type.value,
         }
 
         if chat_keypad:
@@ -276,33 +293,37 @@ class BotClient:
             payload["inline_keypad"] = dataclasses.asdict(inline_keypad)
         if reply_to_message_id:
             payload["reply_to_message_id"] = str(reply_to_message_id)
-    
-        result = await self._make_request('sendContact', payload)
-        result['chat_id'] = chat_id
-        result['client'] = self
+
+        result = await self._make_request("sendContact", payload)
+        result["chat_id"] = chat_id
+        result["client"] = self
         return MessageId(**result)
 
-    async def get_updates(self, limit: int = 100, offset_id: str = "") -> List[Union[Update, InlineMessage]]:
+    async def get_updates(
+        self, limit: int = 100, offset_id: str = ""
+    ) -> List[Union[Update, InlineMessage]]:
         data = {"limit": limit}
         updates = []
         if offset_id:
             data["offset_id"] = offset_id
         response = await self._make_request("getUpdates", data)
-        
-        if response['updates']:
-            for update in response['updates']:
-                chat_id = update.get('chat_id', '')
+
+        if response["updates"]:
+            for update in response["updates"]:
+                chat_id = update.get("chat_id", "")
                 update = Update(
-                    type=update.get('type', ''),
+                    type=update.get("type", ""),
                     chat_id=chat_id,
                     client=self,
-                    removed_message_id=str(update.get("removed_message_id", ""))
+                    removed_message_id=str(update.get("removed_message_id", "")),
                 )
                 updates.append(update)
 
         return updates
 
-    async def updater(self, limit: int = 100, offset_id: str = "") -> List[Union[Update, InlineMessage]]:
+    async def updater(
+        self, limit: int = 100, offset_id: str = ""
+    ) -> List[Union[Update, InlineMessage]]:
         data = {"limit": limit}
         updates = []
         if offset_id or self.next_offset_id:
@@ -312,15 +333,16 @@ class BotClient:
             response = await self._make_request("getUpdates", data)
             self.next_offset_id = response.get("next_offset_id", self.next_offset_id)
             for item in response.get("updates", []):
-               update = self._parse_update(item)
-               if update:
-                    if update.type == UpdateTypeEnum.REMOVED_MESSAGE:
+                update = self._parse_update(item)
+                if update:
+                    if update.type == UpdateTypeEnum.RemovedMessage:
                         continue
 
                     last_time = (
-                        getattr(update, 'new_message', None) and update.new_message.time
+                        getattr(update, "new_message", None) and update.new_message.time
                     ) or (
-                        getattr(update, 'updated_message', None) and update.updated_message.time
+                        getattr(update, "updated_message", None)
+                        and update.updated_message.time
                     )
 
                     # اگر از آخرین پیام بیشتر از 5 ثانیه گذشته، لیست update رو پاک کن
@@ -339,56 +361,82 @@ class BotClient:
         return updates
 
     async def get_chat(self, chat_id: str) -> Any:
-        result = await self._make_request('getChat', {'chat_id': chat_id})
-        return Chat(**result['chat'])
+        result = await self._make_request("getChat", {"chat_id": chat_id})
+        return Chat(**result["chat"])
 
     async def forward_message(
         self,
         from_chat_id: str,
         message_id: str,
         to_chat_id: str,
-        disable_notification: bool = False
+        disable_notification: bool = False,
     ) -> Any:
         result = await self._make_request(
-            'forwardMessage',
-            {'from_chat_id': from_chat_id, 'message_id': str(message_id), 'to_chat_id': to_chat_id, 'disable_notification': disable_notification}
+            "forwardMessage",
+            {
+                "from_chat_id": from_chat_id,
+                "message_id": str(message_id),
+                "to_chat_id": to_chat_id,
+                "disable_notification": disable_notification,
+            },
         )
-        result['chat_id'] = to_chat_id
-        result['client'] = self
+        result["chat_id"] = to_chat_id
+        result["client"] = self
         return MessageId(**result)
 
     async def edit_message_text(self, chat_id: str, message_id: str, text: str) -> Any:
-        result = await self._make_request('editMessageText', {'chat_id': chat_id, 'message_id': str(message_id), 'text': text})
+        result = await self._make_request(
+            "editMessageText",
+            {"chat_id": chat_id, "message_id": str(message_id), "text": text},
+        )
         if result == {}:
             return True
         return False
 
-    async def edit_message_keypad(self, chat_id: str, message_id: str, inline_keypad: Keypad) -> Any:
-        result = await self._make_request('editMessageKeypad', {'chat_id': chat_id, 'message_id': str(message_id), 'inline_keypad': dataclasses.asdict(inline_keypad)})
+    async def edit_message_keypad(
+        self, chat_id: str, message_id: str, inline_keypad: Keypad
+    ) -> Any:
+        result = await self._make_request(
+            "editMessageKeypad",
+            {
+                "chat_id": chat_id,
+                "message_id": str(message_id),
+                "inline_keypad": dataclasses.asdict(inline_keypad),
+            },
+        )
         if result == {}:
             return True
         return False
 
     async def delete_message(self, chat_id: str, message_id: str) -> Any:
-        result = await self._make_request('deleteMessage', {'chat_id': chat_id, 'message_id': str(message_id)})
+        result = await self._make_request(
+            "deleteMessage", {"chat_id": chat_id, "message_id": str(message_id)}
+        )
         if result == {}:
             return True
         return False
 
     async def set_commands(self, commands: List[Dict[str, str]]) -> Any:
-        result = await self._make_request('setCommands', {'bot_commands': commands})
+        result = await self._make_request("setCommands", {"bot_commands": commands})
         if result == {}:
             return True
         return False
 
     async def update_bot_endpoints(self, url: str, endpoint_type: str):
-        return await self._make_request('updateBotEndpoints', {'url': url, 'type': endpoint_type})
+        return await self._make_request(
+            "updateBotEndpoints", {"url": url, "type": endpoint_type}
+        )
 
-    async def edit_chat_keypad(self, chat_id: str, keypad_type: ChatKeypadTypeEnum, keypad: Optional[Keypad] = None) -> Any:
-        payload = {'chat_id': chat_id, 'chat_keypad_type': keypad_type.value}
+    async def edit_chat_keypad(
+        self,
+        chat_id: str,
+        keypad_type: ChatKeypadTypeEnum,
+        keypad: Optional[Keypad] = None,
+    ) -> Any:
+        payload = {"chat_id": chat_id, "chat_keypad_type": keypad_type.value}
         if keypad:
-            payload['chat_keypad'] = dataclasses.asdict(keypad)
-        result = await self._make_request('editChatKeypad', payload)
+            payload["chat_keypad"] = dataclasses.asdict(keypad)
+        result = await self._make_request("editChatKeypad", payload)
         if result == {}:
             return True
         return False
@@ -399,8 +447,11 @@ class BotClient:
             if filter_key not in self.handlers:
                 self.handlers[filter_key] = []
             self.handlers[filter_key].append((filters, handler))
-            logger.info(f"Registered handler {handler.__name__} with filters: {filters}")
+            logger.info(
+                f"Registered handler {handler.__name__} with filters: {filters}"
+            )
             return handler
+
         return decorator
 
     def _parse_update(self, item: Dict) -> Optional[Union[Update, InlineMessage]]:
@@ -410,15 +461,22 @@ class BotClient:
             return None
 
         chat_id = item.get("chat_id", "")
-        if update_type == UpdateTypeEnum.REMOVED_MESSAGE:
+        if update_type == UpdateTypeEnum.RemovedMessage:
             return Update(
                 client=self,
-                type=UpdateTypeEnum.REMOVED_MESSAGE,
+                type=UpdateTypeEnum.RemovedMessage,
                 chat_id=chat_id,
-                removed_message_id=str(item.get("removed_message_id", ""))
+                removed_message_id=str(item.get("removed_message_id", "")),
+            )
+        elif update_type in [
+            UpdateTypeEnum.NewMessage,
+            UpdateTypeEnum.UpdatedMessage,
+        ]:
+            msg_key = (
+                "new_message"
+                if update_type == UpdateTypeEnum.NewMessage
+                else "updated_message"
             )
-        elif update_type in [UpdateTypeEnum.NEW_MESSAGE, UpdateTypeEnum.UPDATED_MESSAGE]:
-            msg_key = "new_message" if update_type == UpdateTypeEnum.NEW_MESSAGE else "updated_message"
             msg_data = item.get(msg_key)
             if not msg_data:
                 logger.debug(f"Skipping {msg_key} with no message data: {item}")
@@ -427,13 +485,21 @@ class BotClient:
             msg_data["message_id"] = str(msg_data.get("message_id", ""))
             try:
                 message_obj = Message(**msg_data)
-                #message_obj = Message.from_dict(msg_data)
+                # message_obj = Message.from_dict(msg_data)
                 return Update(
                     type=update_type,
                     chat_id=chat_id,
                     client=self,
-                    new_message=message_obj if update_type == UpdateTypeEnum.NEW_MESSAGE else None,
-                    updated_message=message_obj if update_type == UpdateTypeEnum.UPDATED_MESSAGE else None
+                    new_message=(
+                        message_obj
+                        if update_type == UpdateTypeEnum.NewMessage
+                        else None
+                    ),
+                    updated_message=(
+                        message_obj
+                        if update_type == UpdateTypeEnum.UpdatedMessage
+                        else None
+                    ),
                 )
             except Exception as e:
                 logger.error(f"Failed to parse message: {msg_data}, error: {str(e)}")
@@ -448,7 +514,7 @@ class BotClient:
                     file=item.get("file"),
                     location=item.get("location"),
                     aux_data=item.get("aux_data"),
-                    client=self
+                    client=self,
                 )
                 logger.info(f"Parsed InlineMessage: {inline_msg}")
                 return inline_msg
@@ -460,43 +526,71 @@ class BotClient:
             return None
 
     async def process_update(self, update: Union[Update, InlineMessage]):
-        update_type = "InlineMessage" if isinstance(update, InlineMessage) else update.type
+        update_type = (
+            "InlineMessage" if isinstance(update, InlineMessage) else update.type
+        )
         message_id = self._extract_message_id(update)
 
         # Skip processed messages check for InlineMessage to avoid issues with repeated message_id
-        if isinstance(update, Update) and message_id and message_id in self.processed_messages:
+        if (
+            isinstance(update, Update)
+            and message_id
+            and message_id in self.processed_messages
+        ):
             logger.debug(f"Skipping processed update ({update_type}): {message_id}")
             return
 
         if message_id and isinstance(update, Update):
             self.processed_messages.append(message_id)
 
-        logger.info(f"Processing update: {update_type}, handlers available: {len(self.handlers)}")
+        logger.info(
+            f"Processing update: {update_type}, handlers available: {len(self.handlers)}"
+        )
         handled = False
         for filter_key, handler_list in self.handlers.items():
-            logger.info(f"Checking handler list {filter_key} with {len(handler_list)} handlers")
+            logger.info(
+                f"Checking handler list {filter_key} with {len(handler_list)} handlers"
+            )
             for filters, handler in handler_list:
-                logger.info(f"Checking filters for handler {handler.__name__}: {filters}")
+                logger.info(
+                    f"Checking filters for handler {handler.__name__}: {filters}"
+                )
                 if await self._filters_pass(update, filters):
                     try:
-                        logger.info(f"Executing handler {handler.__name__} for update {update_type}")
+                        logger.info(
+                            f"Executing handler {handler.__name__} for update {update_type}"
+                        )
                         if asyncio.iscoroutinefunction(handler):
                             asyncio.create_task(handler(self, update))
                         else:
-                            threading.Thread(target=handler, args=(self, update,)).start()
+                            threading.Thread(
+                                target=handler,
+                                args=(
+                                    self,
+                                    update,
+                                ),
+                            ).start()
                         handled = True
                     except Exception as e:
-                        logger.exception(f"Error in handler {handler.__name__}: {str(e)}")
+                        logger.exception(
+                            f"Error in handler {handler.__name__}: {str(e)}"
+                        )
                 else:
-                    logger.info(f"Filters {filters} failed for handler {handler.__name__} on update {update_type}")
+                    logger.info(
+                        f"Filters {filters} failed for handler {handler.__name__} on update {update_type}"
+                    )
         if not handled:
-            logger.warning(f"No handlers matched for update {update_type} with data: {update}")
+            logger.warning(
+                f"No handlers matched for update {update_type} with data: {update}"
+            )
 
-    def _extract_message_id(self, update: Union[Update, InlineMessage]) -> Optional[str]:
+    def _extract_message_id(
+        self, update: Union[Update, InlineMessage]
+    ) -> Optional[str]:
         if isinstance(update, InlineMessage):
             return update.message_id
         if isinstance(update, Update):
-            if update.type == UpdateTypeEnum.REMOVED_MESSAGE:
+            if update.type == UpdateTypeEnum.RemovedMessage:
                 return update.removed_message_id
             if update.new_message:
                 return update.new_message.message_id
@@ -504,8 +598,12 @@ class BotClient:
                 return update.updated_message.message_id
         return None
 
-    async def _filters_pass(self, update: Union[Update, InlineMessage], filters: Tuple[Filter, ...]) -> bool:
-        update_type = "InlineMessage" if isinstance(update, InlineMessage) else update.type
+    async def _filters_pass(
+        self, update: Union[Update, InlineMessage], filters: Tuple[Filter, ...]
+    ) -> bool:
+        update_type = (
+            "InlineMessage" if isinstance(update, InlineMessage) else update.type
+        )
 
         for f in filters:
             # اگر کلاس هست (و نه نمونه)، نمونه‌سازی کن
@@ -513,7 +611,9 @@ class BotClient:
                 f = f()
 
             result = await f.check(update)
-            logger.info(f"Filter {f.__class__.__name__} check for update {update_type}: {result}")
+            logger.info(
+                f"Filter {f.__class__.__name__} check for update {update_type}: {result}"
+            )
             if not result:
                 return False
 
@@ -527,7 +627,9 @@ class BotClient:
 
         try:
             data = await request.json()
-            logger.debug(f"Webhook payload for {request.path}: {json.dumps(data, ensure_ascii=False)}")
+            logger.debug(
+                f"Webhook payload for {request.path}: {json.dumps(data, ensure_ascii=False)}"
+            )
             updates = []
 
             # Handle inline_message
@@ -541,13 +643,13 @@ class BotClient:
                         file=data["inline_message"].get("file"),
                         location=data["inline_message"].get("location"),
                         aux_data=data["inline_message"].get("aux_data"),
-                        client=self
+                        client=self,
                     )
                     logger.info(f"Received InlineMessage: {inline_msg}")
                     updates.append(inline_msg)
                 except Exception as e:
                     logger.error(f"Failed to parse InlineMessage: {str(e)}")
-            
+
             # Handle updates
             elif "update" in data:
                 update = self._parse_update(data["update"])
@@ -562,26 +664,38 @@ class BotClient:
             return web.json_response({"status": "OK"})
         except json.JSONDecodeError:
             logger.error("Invalid JSON in webhook request")
-            return web.json_response({"status": "ERROR", "error": "Invalid JSON"}, status=400)
+            return web.json_response(
+                {"status": "ERROR", "error": "Invalid JSON"}, status=400
+            )
         except Exception as e:
             logger.error(f"Webhook error for {request.path}: {str(e)}")
             return web.json_response({"status": "ERROR", "error": str(e)}, status=500)
 
-    async def run(self, webhook_url: Optional[str] = None, path: Optional[str] = '/webhook', host: str = "0.0.0.0", port: int = 8080):
+    async def run(
+        self,
+        webhook_url: Optional[str] = None,
+        path: Optional[str] = "/webhook",
+        host: str = "0.0.0.0",
+        port: int = 8080,
+    ):
         self.use_webhook = bool(webhook_url)
         await self.start()
         if self.use_webhook:
             app = web.Application()
-            webhook_base = path.rstrip('/')
+            webhook_base = path.rstrip("/")
             app.router.add_post(f"{webhook_base}", self.handle_webhook)
             app.router.add_post(f"{webhook_base}/receiveUpdate", self.handle_webhook)
-            app.router.add_post(f"{webhook_base}/receiveInlineMessage", self.handle_webhook)
-            
+            app.router.add_post(
+                f"{webhook_base}/receiveInlineMessage", self.handle_webhook
+            )
+
             webhook_url = f"{webhook_url.rstrip('/')}{webhook_base}"
             for endpoint_type in ["ReceiveUpdate", "ReceiveInlineMessage"]:
                 response = await self.update_bot_endpoints(webhook_url, endpoint_type)
-                logger.info(f"Webhook set for {endpoint_type} to {webhook_url}: {response}")
-            
+                logger.info(
+                    f"Webhook set for {endpoint_type} to {webhook_url}: {response}"
+                )
+
             runner = web.AppRunner(app)
             await runner.setup()
             site = web.TCPSite(runner, host, port)
@@ -603,7 +717,7 @@ class BotClient:
                 except Exception as e:
                     logger.error(f"Polling error: {str(e)}")
                     await asyncio.sleep(2)
-    
+
     async def close(self):
         if not self.session.closed:
             await self.session.close()
@@ -614,7 +728,7 @@ class BotClient:
         save_as: Optional[str] = None,
         progress: Optional[Callable[[int, int], None]] = None,
         chunk_size: int = 65536,
-        as_bytes: bool = False
+        as_bytes: bool = False,
     ) -> Union[str, bytes, None]:
         """
         Downloads a file by file_id.
@@ -675,7 +789,8 @@ class BotClient:
 
                     return save_as
 
+
 def get_extension(content_type: str) -> str:
     """Convert MIME type to file extension (e.g., image/jpeg -> .jpg)."""
     ext = mimetypes.guess_extension(content_type)
-    return ext if ext else ''
\ No newline at end of file
+    return ext if ext else ""
