@@ -1,9 +1,7 @@
 # Filters
 import re
 from typing import List, Optional, Union
-import warnings
 
-from rubpy.bot.enums.forwarded_from_type import ForwardedFromType
 from rubpy.bot.models import Update
 from rubpy.bot.models import InlineMessage
 
